[−][src]Enum sp_state_machine::BackendTrustLevel
pub enum BackendTrustLevel {
Trusted,
Untrusted,
}Storage backend trust level.
Variants
Panics from trusted backends are considered justified, and never caught.
Panics from untrusted backend are caught and interpreted as runtime error. Untrusted backend may be missing some parts of the trie, so panics are not considered fatal.