[−][src]Enum sp_state_machine::ExecutionError
pub enum ExecutionError {
Backend(String),
CodeEntryDoesNotExist,
UnableToGenerateProof,
InvalidProof,
}Externalities Error.
Externalities are not really allowed to have errors, since it's assumed that dependent code would not be executed unless externalities were available. This is included for completeness, and as a transition away from the pre-existing framework.
Variants
Backend(String)Backend error.
The entry :code doesn't exist in storage so there's no way we can execute anything.
Backend is incompatible with execution proof generation process.
Invalid execution proof.