[][src]Enum sp_state_machine::ExecutionStrategy

[]
pub enum ExecutionStrategy {
    NativeWhenPossible,
    AlwaysWasm,
    Both,
    NativeElseWasm,
}
[]

Strategy for executing a call into the runtime.

Variants

NativeWhenPossible
[]

Execute with the native equivalent if it is compatible with the given wasm module; otherwise fall back to the wasm.

AlwaysWasm
[]

Use the given wasm module.

Both
[]

Run with both the wasm and the native variant (if compatible). Report any discrepancy as an error.

NativeElseWasm
[]

First native, then if that fails or is not possible, wasm.

Implementations

impl ExecutionStrategy[src][]

pub fn get_manager<E: Debug, R: Decode + Encode>(
    self
) -> ExecutionManager<DefaultHandler<R, E>>
[src][]

Gets the corresponding manager for the execution strategy.